@@ -3,14 +3,15 @@
 #' This output format function ported a style provided by GitBook
 #' (\url{https://www.gitbook.com}) for R Markdown.
 #' @inheritParams html_chapters
-#' @param fig_caption,number_sections,self_contained,lib_dir,... Arguments to be
-#'   passed to \code{rmarkdown::\link{html_document}()} (\code{...} not
-#'   including \code{toc}, \code{theme}, and \code{template}).
+#' @param fig_caption,number_sections,self_contained,lib_dir,pandoc_args ...
+#'   Arguments to be passed to \code{rmarkdown::\link{html_document}()}
+#'   (\code{...} not including \code{toc}, \code{theme}, and \code{template}).
 #' @param config A list of configuration options for the gitbook style, such as
 #'   the font/theme settings.
 #' @export
 gitbook = function(
-  fig_caption = TRUE, number_sections = TRUE, self_contained = FALSE, lib_dir = 'libs', ...,
+  fig_caption = TRUE, number_sections = TRUE, self_contained = FALSE,
+  lib_dir = 'libs', pandoc_args = NULL, ...,
   split_by = c('chapter', 'chapter+number', 'section', 'section+number', 'rmd', 'none'),
   split_bib = TRUE, config = list()
 ) {
@@ -23,8 +24,15 @@ gitbook = function(
   config = html_document2(
     toc = TRUE, number_sections = number_sections, fig_caption = fig_caption,
     self_contained = self_contained, lib_dir = lib_dir, theme = NULL,
-    template = bookdown_file('templates', 'gitbook.html'), ...
+    template = bookdown_file('templates', 'gitbook.html'),
+    pandoc_args = pandoc_args2(pandoc_args), ...
   )
+  # Pandoc 2.0 starts to use <section> instead of <div> for html (defaults to
+  # html5) output, but unfortunately bookdown heavily relies on <div>, so we
+  # have to use html4
+  if (pandoc2.0()) {
+    config$pandoc$to = 'html4'; config$pandoc$ext = '.html'
+  }
   split_by = match.arg(split_by)
   post = config$post_processor  # in case a post processor have been defined
   config$post_processor = function(metadata, input, output, clean, verbose) {
@@ -58,7 +66,7 @@ write_search_data = function(x) {
   x = matrix(strip_search_text(x), nrow = 3)
   x = apply(x, 2, json_string, toArray = TRUE)
   x = paste0('[\n', paste0(x, collapse = ',\n'), '\n]')
-  writeUTF8(x, output_path('search_index.json'))
+  write_utf8(x, output_path('search_index.json'))
 }
 
 gitbook_dependency = function() {
