@@ -2,6 +2,7 @@
 local({
   args = commandArgs(TRUE)
   if (length(args) >= 3) bookdown::render_book(
-    args[-(1:2)], output_dir = args[1], envir = globalenv(), preview = args[2] == 'TRUE'
+    args[-(1:3)], args[1], output_dir = args[2], envir = globalenv(),
+    preview = args[3] == 'TRUE'
   )
 })
